@@ -1,7 +1,7 @@
 /* asdata.c */
 
 /*
- *  Copyright (C) 1989-2010  Alan R. Baldwin
+ *  Copyright (C) 1989-2021  Alan R. Baldwin
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -72,12 +72,12 @@ jmp_buf jump_env;       /*      compiler dependent structure
  *              char    afn[FILSPC];    File Name
  *      };
  */
-struct  asmf    *asmp;  /*      The pointer to the first assembler
-                         *      source file structure of a linked list
-                         */
 struct  asmf    *asmc;  /*      Pointer to the current
                          *      source input structure
                          */
+struct  asmf    *asmp;  /*      The pointer to the first assembler
+                         *      source file structure of a linked list
+                         */
 struct  asmf    *asmi;  /*      Queued pointer to an include file
                          *      source input structure
                          */
@@ -214,6 +214,8 @@ int     page;           /*      current page number
                          */
 int     lop;            /*      current line number on page
                          */
+time_t	curtim;		/*	pointer to the current time string
+			 */
 int     pass;           /*      assembler pass number
                          */
 int     aflag;          /*      -a, make all symbols global flag
@@ -226,18 +228,24 @@ int     fflag;          /*      -f(f), relocations flagged flag
                          */
 int     gflag;          /*      -g, make undefined symbols global flag
                          */
-int     jflag;          /*      -j, generate debug information flag
+int	jflag;		/*	-j, enable NoICE Debug Symbols
                          */
 int     lflag;          /*      -l, generate listing flag
                          */
+int     nflag;          /*      -n, don't resolve global assigned value symbols flag
+                         */
 int     oflag;          /*      -o, generate relocatable output flag
                          */
 int     pflag;          /*      -p, disable listing pagination
                          */
 int     sflag;          /*      -s, generate symbol table flag
                          */
+int     tflag;          /*      -t, output diagnostic parameters from assembler
+                         */
 int     uflag;          /*      -u, disable .list/.nlist processing flag
                          */
+int     vflag;          /*      -v, enable out of range signed / unsigned errors
+                         */
 int     wflag;          /*      -w, enable wide listing format
                          */
 int     xflag;          /*      -x, listing radix flag
@@ -270,6 +278,8 @@ char    *ep;            /*      pointer into error list
                          */
 char    eb[NERR];       /*      array of generated error codes
                          */
+char	*ex[NERR];	/*	array of error string pointers
+			 */
 char    *ip;            /*      pointer into the assembler-source
                          *      text line in ib[]
                          */
@@ -405,6 +415,28 @@ struct  area    area[] = {
 
 struct  area    *areap; /*      pointer to an area structure
                          */
+/*
+ *	The def structure is used by the .define assembler
+ *	directive to define a substitution string for a
+ *	single word.  The def structure contains the
+ *	string being defined, the string to substitute
+ *	for the defined string, and a link to the next
+ *	def structure.  The defined string is a sequence
+ *	of characters not containing any white space
+ *	(i.e. NO SPACEs or TABs).  The substitution string
+ *	may contain SPACES and/or TABs.
+ *
+ *	struct def
+ *	{
+ *		struct def	*d_dp;		link to next define
+ *		char		*d_id;		defined string
+ *		char		*d_define;	string to substitute for defined string
+ *		int		d_dflag;	(1) .defined / (0) .undefined
+ *	};
+ *
+ *	Pointer to a def structure
+ */
+struct	def	*defp = NULL;
 
 FILE    *lfp;           /*      list output file handle
                          */
@@ -425,7 +457,7 @@ char    *relp = &rel[0];/*      Pointer to R Line Values
  *      an array of character types,
  *      one per ASCII character
  */
-unsigned char   ctype[128] = {
+unsigned char   ctype[256] = {
 /*NUL*/ ILL,    ILL,    ILL,    ILL,    ILL,    ILL,    ILL,    ILL,
 /*BS*/  ILL,    SPACE,  ILL,    ILL,    SPACE,  ILL,    ILL,    ILL,
 /*DLE*/ ILL,    ILL,    ILL,    ILL,    ILL,    ILL,    ILL,    ILL,
@@ -441,14 +473,30 @@ unsigned char   ctype[128] = {
 /*`*/   ETC,    LTR16,  LTR16,  LTR16,  LTR16,  LTR16,  LTR16,  LETTER,
 /*h*/   LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
 /*p*/   LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
-/*x*/   LETTER, LETTER, LETTER, ETC,    BINOP,  ETC,    ETC,    ETC
+/*x*/   LETTER, LETTER, LETTER, ETC,    BINOP,  ETC,    ETC,    ETC,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER,
+        LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER, LETTER
 };
 
 /*
  *      an array of characters which
  *      perform the case translation function
  */
-char    ccase[128] = {
+char    ccase[256] = {
 /*NUL*/ '\000', '\001', '\002', '\003', '\004', '\005', '\006', '\007',
 /*BS*/  '\010', '\011', '\012', '\013', '\014', '\015', '\016', '\017',
 /*DLE*/ '\020', '\021', '\022', '\023', '\024', '\025', '\026', '\027',
@@ -464,5 +512,22 @@ char    ccase[128] = {
 /*`*/   '\140', '\141', '\142', '\143', '\144', '\145', '\146', '\147',
 /*h*/   '\150', '\151', '\152', '\153', '\154', '\155', '\156', '\157',
 /*p*/   '\160', '\161', '\162', '\163', '\164', '\165', '\166', '\167',
-/*x*/   '\170', '\171', '\172', '\173', '\174', '\175', '\176', '\177'
+/*x*/   '\170', '\171', '\172', '\173', '\174', '\175', '\176', '\177',
+        '\200', '\201', '\202', '\203', '\204', '\205', '\206', '\207',
+        '\210', '\211', '\212', '\213', '\214', '\215', '\216', '\217',
+        '\220', '\221', '\222', '\223', '\224', '\225', '\226', '\227',
+        '\230', '\231', '\232', '\233', '\234', '\235', '\236', '\237',
+        '\240', '\241', '\242', '\243', '\244', '\245', '\246', '\247',
+        '\250', '\251', '\252', '\253', '\254', '\255', '\256', '\257',
+        '\260', '\261', '\262', '\263', '\264', '\265', '\266', '\267',
+        '\270', '\271', '\272', '\273', '\274', '\275', '\276', '\277',
+        '\300', '\301', '\302', '\303', '\304', '\305', '\306', '\307',
+        '\310', '\311', '\312', '\313', '\314', '\315', '\316', '\317',
+        '\320', '\321', '\322', '\323', '\324', '\325', '\326', '\327',
+        '\330', '\331', '\332', '\333', '\334', '\335', '\336', '\337',
+        '\340', '\341', '\342', '\343', '\344', '\345', '\346', '\347',
+        '\350', '\351', '\352', '\353', '\354', '\355', '\356', '\357',
+        '\360', '\361', '\362', '\363', '\364', '\365', '\366', '\367',
+        '\370', '\371', '\372', '\373', '\374', '\375', '\376', '\377'
 };
+
