@@ -53,7 +53,9 @@ struct  mne     mne[] = {
     {	NULL,	".include",	S_INCL,		0,	I_CODE	},
     {	NULL,	".incbin",	S_INCL,		0,	I_BNRY	},
     {   NULL,   ".area",        S_AREA,         0,      0       },
-
+//    {	NULL,	".psharea",	S_AREA,		0,	O_PSH	},
+//    {	NULL,	".poparea",	S_AREA,		0,	O_POP	},
+//    {	NULL,	".bank",	S_BANK,		0,	0	},
     {   NULL,   ".org",         S_ORG,          0,      0       },
     {   NULL,   ".radix",       S_RADIX,        0,      0       },
     {   NULL,   ".globl",       S_GLOBL,        0,      0       },
@@ -105,8 +107,10 @@ struct  mne     mne[] = {
     {   NULL,   ".fdb",         S_DATA,         0,      O_2BYTE },
     {   NULL,   ".3byte",       S_DATA,         0,      O_3BYTE },
     {   NULL,   ".triple",      S_DATA,         0,      O_3BYTE },
-/*    { NULL,   ".4byte",       S_DATA,         0,      O_4BYTE },      */
-/*    { NULL,   ".quad",        S_DATA,         0,      O_4BYTE },      */
+/*    {	NULL,	".dl",		S_DATA,		0,	O_4BYTE	},	*/
+/*    {	NULL,	".4byte",	S_DATA,		0,	O_4BYTE	},	*/
+/*    {	NULL,	".quad",	S_DATA,		0,	O_4BYTE	},	*/
+/*    {	NULL,	".long",	S_DATA,		0,	O_4BYTE	},	*/
     {   NULL,   ".df",          S_FLOAT,        0,      0       },
     {   NULL,   ".blkb",        S_BLK,          0,      O_1BYTE },
     {   NULL,   ".ds",          S_BLK,          0,      O_1BYTE },
@@ -115,6 +119,7 @@ struct  mne     mne[] = {
     {   NULL,   ".blkw",        S_BLK,          0,      O_2BYTE },
     {   NULL,   ".blk3",        S_BLK,          0,      O_3BYTE },
 /*    { NULL,   ".blk4",        S_BLK,          0,      O_4BYTE },      */
+/*    {	NULL,	".blkl",	S_BLK,		0,	O_4BYTE	},	*/
     {   NULL,   ".ascii",       S_ASCIX,        0,      O_ASCII },
     {   NULL,   ".ascis",       S_ASCIX,        0,      O_ASCIS },
     {   NULL,   ".asciz",       S_ASCIX,        0,      O_ASCIZ },
@@ -159,6 +164,7 @@ struct  mne     mne[] = {
     {   NULL,   ".z180",        S_CPU,          0,      X_HD64  },
     {   NULL,   ".zxn",         S_CPU,          0,      X_ZXN   },
     {   NULL,   ".ez80",        S_CPU,          0,      X_EZ80  },
+    {   NULL,   ".r800",        S_CPU,          0,      X_R800  },
 
 	/* z80 / hd64180 */
 
@@ -479,7 +485,12 @@ struct  mne     mne[] = {
     {	NULL,	"pea.l",	X_EZ_PEA,	M_L,	0x65	},
     {	NULL,	"pea.s",	X_EZ_PEA,	M_S,	0x65	},
 
-    {	NULL,	"rsmix",	X_EZ_INH2,	0,	0x7E	},
-    {	NULL,	"stmix",	X_EZ_INH2,	S_EOL,	0x7D	}
+    {	NULL,	"rsmix",	X_EZ_INH2,	0,	0x7E                },
+    {	NULL,	"stmix",	X_EZ_INH2,	0,	0x7D                },
 
+	/* Z280 */
+	
+	{	NULL,	"multu",	X_Z280_MULTU,	0,	0xC1	        },
+    {	NULL,	"multuw",	X_Z280_MULTUW,	S_EOL,	0xC3        }
 };
+
