@@ -145,12 +145,6 @@ _hc08_parseOptions (int *pargc, char **argv, int *i)
       return true;
     }
 
-  if (!strcmp (argv[*i], "--oldralloc"))
-    {
-      options.oldralloc = true;
-      return true;
-    }
-
   return false;
 }
 
@@ -162,7 +156,6 @@ static OPTION _hc08_options[] =
     {0, OPTION_SMALL_MODEL, NULL, "8-bit address space for data"},
     {0, OPTION_LARGE_MODEL, NULL, "16-bit address space for data (default)"},
     {0, "--out-fmt-elf", NULL, "Output executable in ELF format" },
-    {0, "--oldralloc", NULL, "Use old register allocator"},
     {0, NULL }
   };
 
@@ -207,13 +200,19 @@ _hc08_getRegName (const struct reg_info *reg)
 }
 
 static void
-_hc08_genAssemblerPreamble (FILE * of)
+_hc08_genAssemblerStart (FILE * of)
 {
   int i;
   int needOrg = 1;
   symbol *mainExists=newSymbol("main", 0);
   mainExists->block=0;
 
+  if (!options.noOptsdccInAsm)
+    {
+      fprintf (of, "\t.optsdcc -m%s", port->target);
+      fprintf (of, "\n");
+    }
+
   fprintf (of, "\t.area %s\n",HOME_NAME);
   fprintf (of, "\t.area GSINIT0 (CODE)\n");
   fprintf (of, "\t.area %s\n",port->mem.static_name);
@@ -360,18 +359,31 @@ static bool cseCostEstimation (iCode *ic, iCode *pdic)
 
 /* Indicate which extended bit operations this port supports */
 static bool
-hasExtBitOp (int op, int size)
+hasExtBitOp (int op, sym_link *left, int right)
 {
-  if (op == RRC
-      || op == RLC
-      || (op == SWAP && size <= 2)
-      || op == GETABIT
-      || op == GETBYTE
-      || op == GETWORD
-     )
-    return true;
-  else
-    return false;
+  switch (op)
+    {
+    case GETABIT:
+    case GETBYTE:
+    case GETWORD:
+      return true;
+    case ROT:
+      {
+        unsigned int lbits = bitsForType (left);
+        if (lbits % 8)
+          return false;
+        if (lbits == 8)
+          return true;
+        if (lbits > (unsigned)port->support.shift*8)
+          return false;
+        if (right % lbits  == 1 || right % lbits == lbits - 1)
+          return true;
+        if (lbits <= 16 && lbits == right * 2)
+          return true;
+      }
+      return false;
+    }
+  return false;
 }
 
 /* Indicate the expense of an access to an output storage class */
@@ -413,6 +425,8 @@ hc08_dwarfRegNum (const struct reg_info *reg)
 static bool
 _hasNativeMulFor (iCode *ic, sym_link *left, sym_link *right)
 {
+  wassert (ic->op == '*' || ic->op == '/' || ic->op == '%');
+
   if (IS_BITINT (OP_SYM_TYPE (IC_RESULT(ic))) && SPEC_BITINTWIDTH (OP_SYM_TYPE (IC_RESULT(ic))) % 8)
     return false;
 
@@ -756,15 +770,22 @@ hc08_getInstructionSize (lineNode *line)
   return line->aln->size;
 }
 
+static const char *
+s08_get_model (void)
+{
+    return(options.stackAuto ? "s08-stack-auto" : "s08");
+}
+
 /** $1 is always the basename.
     $2 is always the output file.
     $3 varies
     $l is the list of extra options that should be there somewhere...
+    $L is the list of extra options that should be passed on the command line...
     MUST be terminated with a NULL.
 */
 static const char *_linkCmd[] =
 {
-  "sdld6808", "-nf", "$1", NULL
+  "sdld6808", "-nf", "$1", "$L", NULL
 };
 
 /* $3 is replaced by assembler.debug_opts resp. port->assembler.plain_opts */
@@ -859,7 +880,7 @@ PORT hc08_port =
     1           /* sp is offset by 1 from last item pushed */
   },
   {
-    5, false
+    5, false, false
   },
   {
     hc08_emitDebuggerSymbol,
@@ -894,7 +915,7 @@ PORT hc08_port =
   0,
   NULL,
   _hc08_keywords,
-  _hc08_genAssemblerPreamble,
+  _hc08_genAssemblerStart,
   _hc08_genAssemblerEnd,        /* no genAssemblerEnd */
   _hc08_genIVT,
   _hc08_genXINIT,
@@ -935,7 +956,7 @@ PORT s08_port =
     false,                      /* Emit glue around main */
     MODEL_SMALL | MODEL_LARGE,
     MODEL_LARGE,
-    NULL,                       /* model == target */
+    s08_get_model,
   },
   {
     _asmCmd,
@@ -1006,7 +1027,7 @@ PORT s08_port =
     1           /* sp is offset by 1 from last item pushed */
   },
   {
-    5, false
+    5, false, false
   },
   {
     hc08_emitDebuggerSymbol,
@@ -1041,7 +1062,7 @@ PORT s08_port =
   0,
   NULL,
   _hc08_keywords,
-  _hc08_genAssemblerPreamble,
+  _hc08_genAssemblerStart,
   _hc08_genAssemblerEnd,        /* no genAssemblerEnd */
   _hc08_genIVT,
   _hc08_genXINIT,
