@@ -9,7 +9,7 @@
 
 #pragma disable_warning 244
 
-#ifndef __SDCC_pdk14
+#if !defined(__SDCC_pdk14) && !defined(__SDCC_pdk15) // pdk needs functions called via pointer to be reentrant even for a single argument
 const void *p;
 int ret;
 
@@ -94,7 +94,7 @@ f6 ()
 static void
 testFuncPtr (void)
 {
-#ifndef __SDCC_pdk14
+#if !defined(__SDCC_pdk14) && !defined(__SDCC_pdk15)
 #if !((defined __SDCC_stm8) && defined (__SDCC_MODEL_LARGE)) // STM8 large model has sizeof(void *) != size of function pointers.
   f1 ();
   ASSERT (ret == 4);
